<?php
/*
 * @copyright 2023 Passwords Handbook App
 *
 * @author Marius David Wieschollek
 * @license AGPL-3.0
 *
 * This file is part of the Passwords App
 * created by Marius David Wieschollek.
 */

namespace OCA\PasswordsHandbook\Migration;

use Exception;
use OCA\PasswordsHandbook\Service\HandbookUrlService;
use OCP\Migration\IOutput;
use OCP\Migration\IRepairStep;

class UpdateHandbookSettings implements IRepairStep {

    protected HandbookUrlService $handbookUrlService;

    /**
     * @param HandbookUrlService $handbookUrlService
     */
    public function __construct(HandbookUrlService $handbookUrlService) {
        $this->handbookUrlService = $handbookUrlService;
    }

    /**
     * Returns the step's name
     *
     * @return string
     * @since 9.1.0
     */
    public function getName() {
        return 'Update App Settings';
    }

    /**
     * Run repair step.
     * Must throw exception on error.
     *
     * @param IOutput $output
     *
     * @throws Exception in case of failure
     * @since 9.1.0
     */
    public function run(IOutput $output) {
        $this->handbookUrlService->setUrl();
    }
}